package com.ruoyi.project.business.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.project.business.domain.TcProjectEquipment;
import com.ruoyi.project.business.domain.TcProjectEquipmentHistory;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author ruoyi
 * @date 2024-07-22
 */
public interface ITcProjectEquipmentHistoryService extends IService<TcProjectEquipmentHistory>
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TcProjectEquipmentHistory selectTcProjectEquipmentHistoryById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tcProjectEquipmentHistory 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TcProjectEquipmentHistory> selectTcProjectEquipmentHistoryList(TcProjectEquipmentHistory tcProjectEquipmentHistory);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tcProjectEquipmentHistory 【请填写功能名称】
     * @return 结果
     */
    public int insertTcProjectEquipmentHistory(TcProjectEquipmentHistory tcProjectEquipmentHistory);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tcProjectEquipmentHistory 【请填写功能名称】
     * @return 结果
     */
    public int updateTcProjectEquipmentHistory(TcProjectEquipmentHistory tcProjectEquipmentHistory);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteTcProjectEquipmentHistoryByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTcProjectEquipmentHistoryById(Long id);
}
