package com.ruoyi.project.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.business.domain.TcProjectEquipmentHistory;
import com.ruoyi.project.business.service.ITcProjectEquipmentHistoryService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-07-22
 */
@RestController
@RequestMapping("/business/project/equipment/history")
public class TcProjectEquipmentHistoryController extends BaseController
{
    @Autowired
    private ITcProjectEquipmentHistoryService tcProjectEquipmentHistoryService;

    /**
     * 查询【请填写功能名称】列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TcProjectEquipmentHistory tcProjectEquipmentHistory)
    {
        startPage();
        List<TcProjectEquipmentHistory> list = tcProjectEquipmentHistoryService.selectTcProjectEquipmentHistoryList(tcProjectEquipmentHistory);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcProjectEquipmentHistory tcProjectEquipmentHistory)
    {
        List<TcProjectEquipmentHistory> list = tcProjectEquipmentHistoryService.selectTcProjectEquipmentHistoryList(tcProjectEquipmentHistory);
        ExcelUtil<TcProjectEquipmentHistory> util = new ExcelUtil<TcProjectEquipmentHistory>(TcProjectEquipmentHistory.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcProjectEquipmentHistoryService.selectTcProjectEquipmentHistoryById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcProjectEquipmentHistory tcProjectEquipmentHistory)
    {
        return toAjax(tcProjectEquipmentHistoryService.insertTcProjectEquipmentHistory(tcProjectEquipmentHistory));
    }

    /**
     * 修改【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcProjectEquipmentHistory tcProjectEquipmentHistory)
    {
        return toAjax(tcProjectEquipmentHistoryService.updateTcProjectEquipmentHistory(tcProjectEquipmentHistory));
    }

    /**
     * 删除【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcProjectEquipmentHistoryService.deleteTcProjectEquipmentHistoryByIds(ids));
    }
}
